pygeodesy.frechet.Frechet6Tuple

Package pygeodesy :: Module frechet :: Class Frechet6Tuple |
[frames] | no frames]

# Class Frechet6Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Frechet6Tuple

6-Tuple `(fd, fi1, fi2, r, n, units)` with the discrete Fréchet distance `fd`, fractional indices `fi1` and `fi2` as `FIx`, the recursion depth `r`, the number of distances computed `n` and the units class or name of the distance `units`.

Empirically, the recursion depth `r ≈ 2 * sqrt(len(point1s) * len(point2s))` or `0` if non-recursive, see function frechet_.

If fractional indices `fi1` and `fi2` are `int`, the returned `fd` is the distance between `point1s[fi1]` and `point2s[fi2]`. For `float` indices, the distance is between an intermediate point along `point1s[int(fi1)]` and `point1s[int(fi1) + 1]` respectively an intermediate point along `point2s[int(fi2)]` and `point2s[int(fi2) + 1]`.

Use function fractional to compute the point at a fractional index.

Instance Methods
toUnits(self, **Error_name) Overloaded `_NamedTuple.toUnits` for `fd` units. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toUnits (self, **Error_name) |
Overloaded `_NamedTuple.toUnits` for `fd` units. Arguments: `Error` - Error to raise for units issues (`UnitError`). `name` - Optional `name=NN` (`str`). Returns: A duplicate of this `Named-Tuple` (``Named-Tuple``). Raises: `Error` - Invalid `Named-Tuple` item or units class. Overrides: named._NamedTuple.toUnits